@@ -75,9 +75,12 @@ class Commander:
 
     def configure(self):
         if self.project.exists():
-            msg = "Project %s already exists" % self.project.name
-            logging.error(msg)
-            raise CommanderError(msg)
+            if self.env.force_configure:
+                self.project.remove()
+            else:
+                msg = "Project %s already exists" % self.project.name
+                logging.error(msg)
+                raise CommanderError(msg)
 
         # Check 3rd party SW versions
         self.project.check_versions()
