@@ -1,6 +1,36 @@
 from . import SpecValidator
 
 EDBRA1Spec = {
+    'dbt2': SpecValidator(
+        type='choice',
+        choices=[True, False],
+        default=False
+    ),
+    'dbt2_client': {
+        'count': SpecValidator(
+            type='integer',
+            min=0,
+            max=64,
+            default=0
+        ),
+    },
+    'dbt2_driver': {
+        'count': SpecValidator(
+            type='integer',
+            min=0,
+            max=64,
+            default=0
+        ),
+    },
+    'available_os': {
+        'RockyLinux8': {
+            'image': SpecValidator(
+                type='string',
+                default='generic/rocky8',
+            ),
+        },
+    },
+    'ipv4': SpecValidator(type='ipv4', default='192.168.56.101'),
     'ssh_user': SpecValidator(type='string', default=None),
     'pg_data': SpecValidator(type='string', default=None),
     'pg_wal': SpecValidator(type='string', default=None),
